@@ -119,8 +119,14 @@ GS_EXPORT NSString* const NSLoadedClasses;
   unsigned		_version;
   NSString      	*_frameworkVersion;
 #endif
-#if	!GS_NONFRAGILE
-  void			*_unused;
+#if     GS_NONFRAGILE
+#else
+  /* Pointer to private additional data used to avoid breaking ABI
+   * when we don't have the non-fragile ABI available.
+   * Use this mechanism rather than changing the instance variable
+   * layout (see Source/GSInternal.h for details).
+   */
+  @private id _internal GS_UNUSED_IVAR;
 #endif
 }
 
@@ -302,9 +308,16 @@ GS_EXPORT NSString* const NSLoadedClasses;
    localized equivalent found.  This can be useful during development to check
    where a given string in the UI is "coming from".</p>
  */
+#ifdef __clang__
+- (NSString*) localizedStringForKey: (NSString*)key
+			      value: (NSString*)value
+			      table: (NSString*)tableName
+				  __attribute__((format_arg(1)));
+#else
 - (NSString*) localizedStringForKey: (NSString*)key
 			      value: (NSString*)value
 			      table: (NSString*)tableName;
+#endif
 
 /** Returns the absolute path to the resources directory of the bundle.  */
 - (NSString*) resourcePath;
